@@ -2,14 +2,78 @@
 A module to contain all the functions that parse command line arguments, and their error classes.
 """
 
-from typing import Dict, NoReturn, Optional
+from typing import Dict, NoReturn, Optional, Tuple
 import logging
 
 from wheatley.aliases import CallDef, JSON
+from wheatley.bell import Bell
 from wheatley.row_generation import RowGenerator
 from wheatley.row_generation.place_notation_generator import PlaceNotationGenerator
-from wheatley.row_generation.complib_composition_generator import ComplibCompositionGenerator, \
-                                                                  PrivateCompError, InvalidCompError
+from wheatley.row_generation.complib_composition_generator import (
+    ComplibCompositionGenerator,
+    PrivateCompError,
+    InvalidCompError,
+)
+from wheatley.row_generation.helpers import valid_pn
+
+
+class StartRowParseError(ValueError):
+    """
+    An error thrown with a helpful error message when the user inputs a start row string that
+    cannot be parsed by the parser.
+    """
+
+    def __init__(self, start_row_string: str, message: str) -> None:
+        super().__init__()
+
+        self.start_row_string = start_row_string
+        self.message = message
+
+    def __str__(self) -> str:
+        return f"Error parsing start row '{self.start_row_string}': {self.message}"
+
+
+def parse_start_row(start_row: str) -> int:
+    """
+    Parses a start row written in the format "12345" to ensure all characters are valid bells
+    and there are no missing bells.
+    """
+
+    def exit_with_message(error_text: str) -> NoReturn:
+        """Raise an exception with a useful error message."""
+        raise StartRowParseError(start_row, error_text)
+
+    if start_row is None:
+        return 0
+
+    max_bell: int = 0
+
+    if start_row is None:
+        return max_bell
+
+    # First loop checks for invalid bells and finds the largest bell in the row
+    for char in start_row:
+        try:
+            bell = Bell.from_str(char)
+        except ValueError as e:
+            exit_with_message(str(e))
+
+        max_bell = max(max_bell, bell.number)
+
+    # Second loop checks if there are duplicates and if every bell is specified
+    expected_bells = list(range(1, max_bell + 1))
+    for char in start_row:
+        bell_number = Bell.from_str(char).number
+
+        if bell_number not in expected_bells:
+            exit_with_message(f"Start row contains bell {bell_number} mutiple times")
+
+        expected_bells.remove(bell_number)
+
+    if len(expected_bells) > 0:
+        exit_with_message(f"Start row does not contain bell(s) {expected_bells}")
+
+    return len(start_row)
 
 
 class PealSpeedParseError(ValueError):
@@ -32,8 +96,9 @@ def parse_peal_speed(peal_speed: str) -> int:
     """
     Parses a peal speed written in the format /2h58(m?)/ or /XXX(m?)/ into a number of minutes.
     """
+
     def exit_with_message(error_text: str) -> NoReturn:
-        """ Raise an exception with a useful error message. """
+        """Raise an exception with a useful error message."""
         raise PealSpeedParseError(peal_speed, error_text)
 
     # Strip whitespace from the argument, so that if the user is in fact insane enough to pad their
@@ -109,9 +174,10 @@ class CallParseError(ValueError):
 
 
 def parse_call(input_string: str) -> CallDef:
-    """ Parse a call string into a dict of lead locations to place notation strings. """
+    """Parse a call string into a dict of lead locations to place notation strings."""
+
     def exit_with_message(message: str) -> NoReturn:
-        """ Raises a parse error with the given error message. """
+        """Raises a parse error with the given error message."""
         raise CallParseError(input_string, message)
 
     # A dictionary that will be filled with the parsed calls
@@ -127,9 +193,7 @@ def parse_call(input_string: str) -> CallDef:
             try:
                 location_str, place_notation_str = segment.split(":")
             except ValueError:
-                exit_with_message(
-                    f"Call specification '{segment.strip()}' should contain at most one ':'."
-                )
+                exit_with_message(f"Call specification '{segment.strip()}' should contain at most one ':'.")
 
             # Strip whitespace from the string segments so that they can be parsed more easily
             assert place_notation_str is not None
@@ -152,8 +216,10 @@ def parse_call(input_string: str) -> CallDef:
 
         # Insert the new call definition into the dictionary
         if location in parsed_calls:
-            exit_with_message(f"Location {location} has two conflicting calls: \
-'{parsed_calls[location]}' and '{place_notation_str}'.")
+            exit_with_message(
+                f"Location {location} has two conflicting calls: \
+'{parsed_calls[location]}' and '{place_notation_str}'."
+            )
 
         parsed_calls[location] = place_notation_str
 
@@ -161,7 +227,8 @@ def parse_call(input_string: str) -> CallDef:
 
 
 class RowGenParseError(ValueError):
-    """ A class to encapsulate an error generated when parsing an RowGenerator from JSON. """
+    """A class to encapsulate an error generated when parsing an RowGenerator from JSON."""
+
     def __init__(self, json: JSON, field: str, message: str) -> None:
         super().__init__()
 
@@ -177,15 +244,16 @@ class RowGenParseError(ValueError):
 
 
 def json_to_row_generator(json: JSON, logger: logging.Logger) -> RowGenerator:
-    """ Takes a JSON message from SocketIO and convert it to a RowGenerator or throw an exception. """
+    """Takes a JSON message from SocketIO and convert it to a RowGenerator or throw an exception."""
+
     def raise_error(field: str, message: str, parent_error: Optional[Exception] = None) -> NoReturn:
-        """ A helper function to raise a `RowGenParseError` with a helpful error message. """
+        """A helper function to raise a `RowGenParseError` with a helpful error message."""
         if parent_error is None:
             raise RowGenParseError(json, field, message)
         raise RowGenParseError(json, field, message) from parent_error
 
     def json_to_call(name: str) -> Optional[CallDef]:
-        """ Helper function to generate a call with a given name from the json. """
+        """Helper function to generate a call with a given name from the json."""
         if name not in json:
             logger.warning(f"No field '{name}' in the row generator JSON")
             return None
@@ -199,34 +267,33 @@ def json_to_row_generator(json: JSON, logger: logging.Logger) -> RowGenerator:
             call[index] = value
         return CallDef(call)
 
-    if 'type' not in json:
-        raise_error('type', "'type' is not defined")
+    if "type" not in json:
+        raise_error("type", "'type' is not defined")
 
-    if json['type'] == 'method':
+    if json["type"] == "method":
         try:
-            stage = int(json['stage'])
+            stage = int(json["stage"])
         except KeyError as e:
-            raise_error('stage', "'stage' is not defined", e)
+            raise_error("stage", "'stage' is not defined", e)
         except ValueError as e:
-            raise_error('stage', f"'{json['stage']}' is not a valid integer", e)
-        return PlaceNotationGenerator(stage, json['notation'], json_to_call('bob'),
-                                      json_to_call('single'))
+            raise_error("stage", f"'{json['stage']}' is not a valid integer", e)
+        return PlaceNotationGenerator(stage, json["notation"], json_to_call("bob"), json_to_call("single"))
 
-    if json['type'] == "composition":
+    if json["type"] == "composition":
         try:
-            comp_url = json['url']
+            comp_url = json["url"]
         except KeyError as e:
-            raise_error('url', "'url' is not defined", e)
+            raise_error("url", "'url' is not defined", e)
 
         try:
             row_gen = ComplibCompositionGenerator.from_arg(comp_url)
         except PrivateCompError as e:
-            raise_error('complib request', "Comp id '{comp_url}' is private", e)
+            raise_error("complib request", "Comp id '{comp_url}' is private", e)
         except InvalidCompError as e:
-            raise_error('complib request', "No composition with id '{comp_url}' found", e)
+            raise_error("complib request", "No composition with id '{comp_url}' found", e)
         return row_gen
 
-    raise_error('type', f"{json['type']} is not one of 'method' or 'composition'")
+    raise_error("type", f"{json['type']} is not one of 'method' or 'composition'")
 
 
 def to_bool(value: str) -> bool:
@@ -239,3 +306,42 @@ def to_bool(value: str) -> bool:
     if value in ["False", "false", False]:
         return False
     raise ValueError(f"Value {value} cannot be converted into a bool")
+
+
+class PlaceNotationError(ValueError):
+    """
+    An error thrown with a helpful error message when the user inputs a place
+    notation string that cannot be parsed.
+    """
+
+    def __init__(self, place_notation: str, message: str) -> None:
+        super().__init__()
+
+        self.place_notation = place_notation
+        self.message = message
+
+    def __str__(self) -> str:
+        return f"Error in place notation '{self.place_notation}': {self.message}"
+
+
+def parse_place_notation(input_string: str) -> Tuple[int, str]:
+    """
+    Parse a stage and place notation throwing an error when an invalid stage
+    or place notation specifier is found
+    """
+
+    # Looking for a string that matches <stage>:<place notation> where the
+    # place notation is a series of bell numbers and 'x' characters
+    parts = input_string.split(":")
+    if len(parts) == 2:
+        stage_part = parts[0]
+        if len(stage_part) == 0 or not stage_part.isnumeric():
+            raise PlaceNotationError(input_string, "Stage must be a number")
+        stage = int(stage_part)
+        place_notation = parts[1]
+        if not valid_pn(place_notation):
+            raise PlaceNotationError(input_string, "Place notation is invalid")
+    else:
+        raise PlaceNotationError(input_string, "<stage>:<place notation> required")
+
+    return stage, place_notation
