@@ -40,9 +40,9 @@ def calculate_regression(data_set: List[Tuple[float, float, float]]) -> Tuple[fl
 
     num_datapoints = len(weights)
 
-    x = numpy.array([[1, b] for b in blow_times])
-    w = numpy.array([fill(i, w, num_datapoints) for (i, w) in enumerate(weights)])
-    y = numpy.array([[x] for x in real_times])
+    x: numpy.ndarray = numpy.array([[1, b] for b in blow_times])
+    w: numpy.ndarray = numpy.array([fill(i, w, num_datapoints) for (i, w) in enumerate(weights)])
+    y: numpy.ndarray = numpy.array([[x] for x in real_times])
 
     # Calculate (X^T * W * X)^-1 * (X^T * W * y)
     beta = numpy.linalg.inv(x.transpose().dot(w).dot(x)).dot(x.transpose()).dot(w).dot(y)
@@ -137,7 +137,7 @@ class RegressionRhythm(Rhythm):
         # Wheatley is ringing)
         blow_time = self.index_to_blow_time(row_number, place)
         self.data_set.append((blow_time, real_time, weight))
-        for (b, r, w) in self.data_set:
+        for b, r, w in self.data_set:
             self.logger.debug(f"Datapoint: {b:4.1f} {r - self._real_start_time:8.3f}s {w:.3f}")
         # Filter out datapoints with extremely low weights
         self.data_set = list(filter(lambda d: d[2] > WEIGHT_REJECTION_THRESHOLD, self.data_set))
@@ -273,7 +273,7 @@ class RegressionRhythm(Rhythm):
 
             # Calculate the weight (which will be 1 if it is either of the first two bells to be
             # rung to not skew the data from the start)
-            weight = math.exp(-(diff ** 2))
+            weight = math.exp(-(diff**2))
             if len(self.data_set) <= 1:
                 weight = 1
 
